import numpy

NEURON_GROUPS = []
CONNECTIONS = []
TIMINGS = []

class NeuronGroup:

	def __init__(self, name, particles, count, areaStart):
		self.name = name
		self.particles = particles
		self.count = count
		self.areaStart = areaStart
		self.areaEnd = areaStart + count
		self.connections = []


def readData(connectionsPath, neuronTimingPath):

	if not connectionsPath[-1] == "/":
		connectionsPath += "/"

	# Open neurongroups.csv
	neuronGroupsFile = open(connectionsPath + "neurongroups.csv", 'r')

	neuronGroups = []
	i = 0

	# Gather neuron group information from file
	for l in neuronGroupsFile:
		properties = l.split(";")

		# First element: group name
		name = properties[0]
		if name.startswith('"') and name.endswith('"'):
			name = name[1:-1]

		# particle object name
		particleName = properties[1]
		if particleName.startswith('"') and particleName.endswith('"'):
			particleName = particleName[1:-1]
		
		# number of neurons
		count = int(properties[2])

		neuronGroups.append(NeuronGroup(name, particleName, count, i))
		i += count

	neuronGroupsFile.close()

	# Open the connections file
	connectionsFile = open(connectionsPath + "connections.csv", 'r')
	maxConnectionFiles = 0

	# Add connections to neuron groups
	for l in connectionsFile:
		s = l.split(";")
		connectionID = int(s[0])
		groupFrom = int(s[1])
		groupTo = int(s[2])
		neuronGroups[groupFrom].connections.append((connectionID, groupFrom, groupTo))
		if connectionID > maxConnectionFiles:
			maxConnectionFiles = connectionID;

	connectionsFile.close()
	
	connections = []	
	
	for i in range(maxConnectionFiles + 1):
		neuronConnectionFile = open(connectionsPath + str(i) + "_c.csv")
		neuronDistanceFile = open(connectionsPath + str(i) + "_d.csv")
		c_elem = []
		d_elem = []
		for line in neuronConnectionFile:
			c_elem.append([int(i) for i in line.split(';')])
		for line in neuronDistanceFile:
			d_elem.append([float(i) for i in line.split(';')])
		connections.append({'c': numpy.array(c_elem), 'd': numpy.array(d_elem)})

		neuronConnectionFile.close()
		neuronDistanceFile.close()

	# Open timing file (output.csv)
	timingFile = open(neuronTimingPath, 'r')
	
	# Holds the timing information. (ID in group, neuron group index, fireTime)
	timings = []
	# Iterate through every entry
	for l in timingFile:
		s = l.split(";")
		
		neuronID = int(s[0])
		fireTime = float(s[1])

		# Identify neuron group for given neuron
		for i, n in enumerate(neuronGroups):
			if n.areaStart <= neuronID and n.areaEnd > neuronID:
				neuronGroup = n
				neuronGroupID = i
				break
		neuronIDinGroup = neuronID - neuronGroup.areaStart

		timings.append((neuronIDinGroup, neuronGroupID, fireTime))
	timingFile.close()

	global NEURON_GROUPS
	global CONNECTIONS
	global TIMINGS
	NEURON_GROUPS = neuronGroups
	CONNECTIONS = connections
	TIMINGS = timings

# Testing
if __name__ == "__main__":
	readData("../../../hippocampus_full/", "../../../output.csv")