import bpy

from .. import pam_vis
from .. import model
from . import data

def followCurve(curve, startFrame, color, meshData):
	obj = bpy.data.objects.new("Neuron", meshData)
	obj.color = color
	bpy.context.scene.objects.link(obj)
	constraint = obj.constraints.new(type="FOLLOW_PATH")
	constraint.offset = startFrame / curve.data["timeLength"] * 100
	constraint.target = curve
	
	# For eventual camera tracking
	# camConstraint = obj.constraints.new(type="TRACK_TO")
	# camConstraint.target = bpy.context.scene.camera
	# camConstraint.track_axis = "TRACK_Z"
	# camConstraint.up_axis = "UP_Y"

def setAnimationSpeed(curve, animationSpeed):
	curve.eval_time = 0
	curve.keyframe_insert(data_path = "eval_time", frame = 0)
	curve.eval_time = 100
	curve.keyframe_insert(data_path = "eval_time", frame = animationSpeed)

	# Set all the keyframes to linear interpolation to ensure a constant speed along the curve
	for key in curve.animation_data.action.fcurves[0].keyframe_points:
		key.interpolation = 'LINEAR'
	# Set the extrapolation of the curve to linear (This is important, without it, neurons with an offset start would not be animated)
	curve.animation_data.action.fcurves[0].extrapolation = 'LINEAR'

def timeToFrames(t):
	# TODO: calculate the right ratio from data in animationTools.py
	return int(t * 10);

def visualize():
	n = data.NEURON_GROUPS
	c = data.CONNECTIONS
	t = data.TIMINGS

	# Dictionary for generated curves, so we don't need to generate them twice
	curves = {}

	for timing in t:
		neuronID = timing[0]
		neuronGroupID = timing[1]
		fireTime = timing[2]

		neuronGroup = n[neuronGroupID]
		for connectionID in neuronGroup.connections:
			for index, i in enumerate(c[connectionID[0]]["c"][neuronID]):
				if i == -1:
					continue
				if (connectionID[0], neuronID, i) not in curves.keys():
					# If we do not have a curve already generated, we generate a new one with PAM and save it in our dictionary
					#print("Calling visualizeOneConnection with " + str(connectionID[0]) + ", " + str(neuronID)+ ", " + str(i))
					curve = curves[(connectionID[0], neuronID, i)] = pam_vis.visualizeOneConnection(connectionID[0], neuronID, i)

					# The generated curve needs the right animation speed, so we set the custom property and generate the animation
					curve.data["timeLength"] = timeToFrames(c[connectionID[0]]["d"][neuronID][index])
					#print(curve)
					setAnimationSpeed(curve.data, timeToFrames(c[connectionID[0]]["d"][neuronID][index]))
				else:
					curve = curves[(connectionID[0], neuronID, i)]
				startFrame = timeToFrames(fireTime)
				followCurve(curve, startFrame, (0.0, 0.0, 1.0, 1.0), bpy.data.meshes["Cube"]) 

# Operators:
class GenerateOperator(bpy.types.Operator):
	"""Generate everything"""

	bl_idname = "pam_anim.generate"
	bl_label = "Generate"
	bl_description = "Generates the animation"

	@classmethod
	def poll(cls, context):
		# Return True if all data is accessible
		return True

	def execute(self, context):
		data.readData("D:/Dropbox/python/pam/hippocampus_full", "D:/Dropbox/python/pam/output.csv")
		#data.readData("C:/Users/PatLaptop/Dropbox/python/pam/hippocampus_full", "C:/Users/PatLaptop/Dropbox/python/pam/output.csv")
		visualize()
		return {'FINISHED'}

	def invoke(self, context, event):
		# Gather data
		return self.execute(context)

def register():
	# Custom property for the length of a curve for easy accessibility
	bpy.types.Curve.timeLength = bpy.props.IntProperty()

	bpy.utils.register_class(GenerateOperator)

def unregister():
	bpy.utils.unregister_class(GenerateOperator)